@@ -25,7 +25,7 @@ def exec_command(args, parser):
 
     if args.command == "project": 
         if args.action == "pull":
-            cli_functions.pull_project(args.project, args.approved_only)
+            cli_functions.pull_project(args.project, args.format, args.approved_only)
         elif args.action == "push":
             cli_functions.push_to_project(args.project, args.path)
         elif args.action == "list":
